==> spip_4.0.4.orig.tar.xz: plugins-dist/sites/lang/sites_en_hx.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=en_hx
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => '5ynd1c4710n f4113d: 317h3r 7h3 5313c73d b4ck3nd 15 unr34d4b13 0r 17 d035 n07 0ff3r 4ny 4r71c13.',
	'avis_echec_syndication_02' => '5ynd1c4710n f4113d: c0u1d n07 r34ch 7h3 b4ck3nd 0f 7h15 5173.',
	'avis_site_introuvable' => '5173 n07 f0und',
	'avis_site_syndique_probleme' => 'W4rn1ng: 7h3 5ynd1c4710n 0f 7h15 5173 3nc0un73r3d 4 pr0b13m; c0n53qu3n71y 7h3 5y573m 15 73mp0r4r11y 1n73rrup73d. P13453 v3r1fy 7h3 4ddr355 0f 7h15 5173’5 5ynd1c4710n f113 (<b>@url_syndic@</b>), 4nd 7ry 4g41n 70 p3rf0rm 4 n3w r3c0v3ry 0f 1nf0rm4710n.', # MODIF
	'avis_sites_probleme_syndication' => '7h353 51735 3nc0un73r3d 4 5ynd1c4710n pr0b13m',
	'avis_sites_syndiques_probleme' => '7h353 5ynd1c473d 51735 g3n3r473d 4 pr0b13m',

	// B
	'bouton_radio_modere_posteriori' => '4f73rw4rd5 m0d3r4710n', # MODIF
	'bouton_radio_modere_priori' => 'b3f0r3h4nd m0d3r4710n', # MODIF
	'bouton_radio_non_syndication' => 'N0 5ynd1c4710n',
	'bouton_radio_syndication' => '5ynd1c4710n:',

	// E
	'entree_adresse_fichier_syndication' => '4ddr355 0f &14qu0;b4ck3nd&r4qu0; f113 f0r 5ynd1c4710n:',
	'entree_adresse_site' => '<b>5173 UR1</b> [R3qu1r3d]',
	'entree_description_site' => '5173 d35cr1p710n',

	// F
	'form_prop_nom_site' => '5173\\’5 n4m3',

	// I
	'icone_modifier_site' => 'M0d1fy 7h15 5173',
	'icone_referencer_nouveau_site' => 'R3f3r3nc3 4 n3w 5173',
	'icone_voir_sites_references' => '5h0w r3f3r3nc3d 51735',
	'info_1_site' => '1 5173',
	'info_a_valider' => '[70 b3 v411d473d]',
	'info_bloquer_lien' => 'b10ck 7h15 11nk',
	'info_derniere_syndication' => '7h3 1457 5ynd1c4710n 0f 7h15 5173 w45 c4rr13d 0u7 0n',
	'info_liens_syndiques_1' => '5ynd1c473d 11nk5',
	'info_liens_syndiques_2' => 'p3nd1ng v411d4710n.',
	'info_nom_site_2' => '<b>5173 n4m3</b> [R3qu1r3d]',
	'info_panne_site_syndique' => '5ynd1c473d 5173 0u7 0f 0rd3r',
	'info_probleme_grave' => '3rr0r 0f',
	'info_question_proposer_site' => 'Wh0 c4n pr0p053 r3f3r3nc3d 51735?',
	'info_retablir_lien' => 'r3570r3 7h15 11nk',
	'info_site_attente' => 'W3b 5173 p3nd1ng v411d4710n',
	'info_site_propose' => '5173 5ubm1773d 0n:',
	'info_site_reference' => 'R3f3r3nc3d 51735 0n11n3',
	'info_site_refuse' => 'W3b 5173 r3j3c73d',
	'info_site_syndique' => '7h15 5173 15 5ynd1c473d...', # MODIF
	'info_site_valider' => '51735 70 b3 v411d473d',
	'info_sites_referencer' => 'R3f3r3nc1ng 4 5173',
	'info_sites_refuses' => 'R3j3c73d 51735',
	'info_statut_site_1' => '7h15 5173 15:',
	'info_statut_site_2' => 'Pub115h3d',
	'info_statut_site_3' => '5ubm1773d',
	'info_statut_site_4' => '1n 7h3 du57b1n', # MODIF
	'info_syndication' => '5ynd1c4710n:', # MODIF
	'info_syndication_articles' => '4r71c13(5)',
	'item_bloquer_liens_syndiques' => 'B10ck 5ynd1c473d 11nk5 f0r v411d4710n',
	'item_gerer_annuaire_site_web' => 'M4n4g3 W3b 51735 d1r3c70ry',
	'item_non_bloquer_liens_syndiques' => 'D0 n07 b10ck 7h3 11nk5 3m4n471ng fr0m 5ynd1c4710n',
	'item_non_gerer_annuaire_site_web' => 'D154b13 W3b 51735 d1r3c70ry',
	'item_non_utiliser_syndication' => 'D0 n07 u53 4u70m473d 5ynd1c4710n',
	'item_utiliser_syndication' => 'U53 4u70m473d 5ynd1c4710n',

	// L
	'lien_mise_a_jour_syndication' => 'Upd473 n0w',
	'lien_nouvelle_recuperation' => '7ry 70 p3rf0rm 4 n3w r37r13v41 0f d474',

	// T
	'texte_liens_sites_syndiques' => '11nk5 3m4n471ng fr0m 5ynd1c473d 51735 c0u1d
			b3 b10ck3d b3f0r3h4nd; 7h3 f0110w1ng
			53771ng 5h0w 7h3 d3f4u17 53771ng 0f
			5ynd1c473d 51735 4f73r 7h31r cr34710n. 17
			15, 7h3n, p0551b13 4nyw4y 70
			b10ck 34ch 11nk 1nd1v1du411y, 0r 70
			ch0053, f0r 34ch 5173, 70 b10ck 7h3 11nk5 c0m1ng
			fr0m 4ny p4r71cu14r 5173.', # MODIF
	'texte_messages_publics' => 'Pub11c M3554g35 0f 7h3 4r71c13:',
	'texte_non_fonction_referencement' => 'Y0u c4n ch0053 n07 70 u53 7h15 4u70m473d f347ur3, 4nd 3n73r 7h3 313m3n75 c0nc3rn1ng 7h47 5173 m4nu411y...', # MODIF
	'texte_referencement_automatique' => '<b>4u70m473d 5173 r3f3r3nc1ng</b><br />Y0u c4n r3f3r3nc3 4 W3b 5173 qu1ck1y by 1nd1c471ng b310w 7h3 d351r3d UR1, 0r 7h3 4ddr355 0f 175 b4ck3nd f113. 5P1P w111 4u70m471c411y p1ck up 7h3 1nf0rm4710n c0nc3rn1ng 7h47 5173 (71713, d35cr1p710n...).', # MODIF
	'texte_syndication' => '1f 4 5173 4110w5 17, 17 15 p0551b13 70 r37r13v3 4u70m471c411y
		7h3 1157 0f 175 147357 m473r141. 70 4ch13v3 7h15, y0u mu57 4c71v473 7h3 5ynd1c4710n. 
		<b10ckqu073><1>50m3 h0575 d154b13 7h15 func710n; 
		1n 7h15 c453, y0u c4nn07 u53 7h3 c0n73n7 5ynd1c4710n
		fr0m y0ur 5173.</1></b10ckqu073>', # MODIF
	'titre_articles_syndiques' => '5ynd1c473d 4r71c135 pu113d 0u7 fr0m 7h15 5173',
	'titre_dernier_article_syndique' => '147357 5ynd1c473d 4r71c135',
	'titre_page_sites_tous' => 'R3f3r3nc3d 51735',
	'titre_referencement_sites' => '51735 r3f3r3nc1ng 4nd 5ynd1c4710n',
	'titre_site_numero' => '5173 NUMB3R:',
	'titre_sites_proposes' => '5ubm1773d 51735',
	'titre_sites_references_rubrique' => 'R3f3r3nc3d 51735 1n 7h15 53c710n',
	'titre_sites_syndiques' => '5ynd1c473d 51735',
	'titre_sites_tous' => 'R3f3r3nc3d 51735',
	'titre_syndication' => '51735 5ynd1c4710n'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/sites/lang/sites_en_hx.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=en_hx
// ** ne pas modifier le fichier **

return [

	// A
	'avis_echec_syndication_01' => '5ynd1c4710n f4113d: 317h3r 7h3 5313c73d b4ck3nd 15 unr34d4b13 0r 17 d035 n07 0ff3r 4ny 4r71c13.',
	'avis_echec_syndication_02' => '5ynd1c4710n f4113d: c0u1d n07 r34ch 7h3 b4ck3nd 0f 7h15 5173.',
	'avis_site_introuvable' => '5173 n07 f0und',
	'avis_site_syndique_probleme' => 'W4rn1ng: 7h3 5ynd1c4710n 0f 7h15 5173 3nc0un73r3d 4 pr0b13m; c0n53qu3n71y 7h3 5y573m 15 73mp0r4r11y 1n73rrup73d. P13453 v3r1fy 7h3 4ddr355 0f 7h15 5173’5 5ynd1c4710n f113 (<b>@url_syndic@</b>), 4nd 7ry 4g41n 70 p3rf0rm 4 n3w r3c0v3ry 0f 1nf0rm4710n.', # MODIF
	'avis_sites_probleme_syndication' => '7h353 51735 3nc0un73r3d 4 5ynd1c4710n pr0b13m',
	'avis_sites_syndiques_probleme' => '7h353 5ynd1c473d 51735 g3n3r473d 4 pr0b13m',

	// B
	'bouton_radio_modere_posteriori' => '4f73rw4rd5 m0d3r4710n', # MODIF
	'bouton_radio_modere_priori' => 'b3f0r3h4nd m0d3r4710n', # MODIF
	'bouton_radio_non_syndication' => 'N0 5ynd1c4710n',
	'bouton_radio_syndication' => '5ynd1c4710n:',

	// E
	'entree_adresse_fichier_syndication' => '4ddr355 0f &14qu0;b4ck3nd&r4qu0; f113 f0r 5ynd1c4710n:',
	'entree_adresse_site' => '<b>5173 UR1</b> [R3qu1r3d]',
	'entree_description_site' => '5173 d35cr1p710n',

	// F
	'form_prop_nom_site' => '5173\\’5 n4m3',

	// I
	'icone_modifier_site' => 'M0d1fy 7h15 5173',
	'icone_referencer_nouveau_site' => 'R3f3r3nc3 4 n3w 5173',
	'icone_voir_sites_references' => '5h0w r3f3r3nc3d 51735',
	'info_1_site' => '1 5173',
	'info_a_valider' => '[70 b3 v411d473d]',
	'info_bloquer_lien' => 'b10ck 7h15 11nk',
	'info_derniere_syndication' => '7h3 1457 5ynd1c4710n 0f 7h15 5173 w45 c4rr13d 0u7 0n',
	'info_liens_syndiques_1' => '5ynd1c473d 11nk5',
	'info_liens_syndiques_2' => 'p3nd1ng v411d4710n.',
	'info_nom_site_2' => '<b>5173 n4m3</b> [R3qu1r3d]',
	'info_panne_site_syndique' => '5ynd1c473d 5173 0u7 0f 0rd3r',
	'info_probleme_grave' => '3rr0r 0f',
	'info_question_proposer_site' => 'Wh0 c4n pr0p053 r3f3r3nc3d 51735?',
	'info_retablir_lien' => 'r3570r3 7h15 11nk',
	'info_site_attente' => 'W3b 5173 p3nd1ng v411d4710n',
	'info_site_propose' => '5173 5ubm1773d 0n:',
	'info_site_reference' => 'R3f3r3nc3d 51735 0n11n3',
	'info_site_refuse' => 'W3b 5173 r3j3c73d',
	'info_site_syndique' => '7h15 5173 15 5ynd1c473d...', # MODIF
	'info_site_valider' => '51735 70 b3 v411d473d',
	'info_sites_referencer' => 'R3f3r3nc1ng 4 5173',
	'info_sites_refuses' => 'R3j3c73d 51735',
	'info_statut_site_1' => '7h15 5173 15:',
	'info_statut_site_2' => 'Pub115h3d',
	'info_statut_site_3' => '5ubm1773d',
	'info_statut_site_4' => '1n 7h3 du57b1n', # MODIF
	'info_syndication' => '5ynd1c4710n:', # MODIF
	'info_syndication_articles' => '4r71c13(5)',
	'item_bloquer_liens_syndiques' => 'B10ck 5ynd1c473d 11nk5 f0r v411d4710n',
	'item_gerer_annuaire_site_web' => 'M4n4g3 W3b 51735 d1r3c70ry',
	'item_non_bloquer_liens_syndiques' => 'D0 n07 b10ck 7h3 11nk5 3m4n471ng fr0m 5ynd1c4710n',
	'item_non_gerer_annuaire_site_web' => 'D154b13 W3b 51735 d1r3c70ry',
	'item_non_utiliser_syndication' => 'D0 n07 u53 4u70m473d 5ynd1c4710n',
	'item_utiliser_syndication' => 'U53 4u70m473d 5ynd1c4710n',

	// L
	'lien_mise_a_jour_syndication' => 'Upd473 n0w',
	'lien_nouvelle_recuperation' => '7ry 70 p3rf0rm 4 n3w r37r13v41 0f d474',

	// T
	'texte_liens_sites_syndiques' => '11nk5 3m4n471ng fr0m 5ynd1c473d 51735 c0u1d
			b3 b10ck3d b3f0r3h4nd; 7h3 f0110w1ng
			53771ng 5h0w 7h3 d3f4u17 53771ng 0f
			5ynd1c473d 51735 4f73r 7h31r cr34710n. 17
			15, 7h3n, p0551b13 4nyw4y 70
			b10ck 34ch 11nk 1nd1v1du411y, 0r 70
			ch0053, f0r 34ch 5173, 70 b10ck 7h3 11nk5 c0m1ng
			fr0m 4ny p4r71cu14r 5173.', # MODIF
	'texte_messages_publics' => 'Pub11c M3554g35 0f 7h3 4r71c13:',
	'texte_non_fonction_referencement' => 'Y0u c4n ch0053 n07 70 u53 7h15 4u70m473d f347ur3, 4nd 3n73r 7h3 313m3n75 c0nc3rn1ng 7h47 5173 m4nu411y...', # MODIF
	'texte_referencement_automatique' => '<b>4u70m473d 5173 r3f3r3nc1ng</b><br />Y0u c4n r3f3r3nc3 4 W3b 5173 qu1ck1y by 1nd1c471ng b310w 7h3 d351r3d UR1, 0r 7h3 4ddr355 0f 175 b4ck3nd f113. 5P1P w111 4u70m471c411y p1ck up 7h3 1nf0rm4710n c0nc3rn1ng 7h47 5173 (71713, d35cr1p710n...).', # MODIF
	'texte_syndication' => '1f 4 5173 4110w5 17, 17 15 p0551b13 70 r37r13v3 4u70m471c411y
		7h3 1157 0f 175 147357 m473r141. 70 4ch13v3 7h15, y0u mu57 4c71v473 7h3 5ynd1c4710n. 
		<b10ckqu073><1>50m3 h0575 d154b13 7h15 func710n; 
		1n 7h15 c453, y0u c4nn07 u53 7h3 c0n73n7 5ynd1c4710n
		fr0m y0ur 5173.</1></b10ckqu073>', # MODIF
	'titre_articles_syndiques' => '5ynd1c473d 4r71c135 pu113d 0u7 fr0m 7h15 5173',
	'titre_dernier_article_syndique' => '147357 5ynd1c473d 4r71c135',
	'titre_page_sites_tous' => 'R3f3r3nc3d 51735',
	'titre_referencement_sites' => '51735 r3f3r3nc1ng 4nd 5ynd1c4710n',
	'titre_site_numero' => '5173 NUMB3R:',
	'titre_sites_proposes' => '5ubm1773d 51735',
	'titre_sites_references_rubrique' => 'R3f3r3nc3d 51735 1n 7h15 53c710n',
	'titre_sites_syndiques' => '5ynd1c473d 51735',
	'titre_sites_tous' => 'R3f3r3nc3d 51735',
	'titre_syndication' => '51735 5ynd1c4710n',
];
